@@ -210,8 +210,10 @@ class Message(JsonDeserializable):
             content_type = 'venue'
         if 'new_chat_member' in obj:
             opts['new_chat_member'] = User.de_json(obj['new_chat_member'])
+            content_type = 'new_chat_member'
         if 'left_chat_member' in obj:
             opts['left_chat_member'] = User.de_json(obj['left_chat_member'])
+            content_type = 'left_chat_member'
         if 'new_chat_title' in obj:
             opts['new_chat_title'] = obj['new_chat_title']
         if 'new_chat_photo' in obj:
@@ -562,7 +564,10 @@ class ReplyKeyboardMarkup(JsonSerializable):
         :param args: strings
         :return: self, to allow function chaining.
         """
-        self.keyboard.append(args)
+        btn_array = []
+        for button in args:
+            btn_array.append(button.to_dic())
+        self.keyboard.append(btn_array)
         return self
 
     def to_json(self):
@@ -636,7 +641,10 @@ class InlineKeyboardMarkup(Dictionaryable, JsonSerializable):
         :param args: strings
         :return: self, to allow function chaining.
         """
-        self.keyboard.append(args)
+        btn_array = []
+        for button in args:
+            btn_array.append(button.to_dic())
+        self.keyboard.append(btn_array)
         return self
 
     def to_json(self):
@@ -1294,6 +1302,7 @@ class InlineQueryResultCachedMpeg4Gif(BaseInlineQueryResultCached):
         self.input_message_content = input_message_content
         self.payload_dic['mpeg4_file_id'] = mpeg4_file_id
 
+
 class InlineQueryResultCachedSticker(BaseInlineQueryResultCached):
     def __init__(self, id, sticker_file_id, reply_markup=None, input_message_content=None):
         BaseInlineQueryResultCached.__init__(self)
